==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/replay/ReplayInputCreationMethods.cpp <==
/*
 * Copyright (C) 2011-2013 University of Washington.
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#if ENABLE(WEB_REPLAY)

#include "Document.h"
#include "MainFrame.h"
#include "Page.h"
#include "SecurityOrigin.h"
#include "SerializationMethods.h"
#include "WebReplayInputs.h"

namespace WebCore {

std::unique_ptr<InitialNavigation> InitialNavigation::createFromPage(const Page& page)
{
    const MainFrame& mainFrame = page.mainFrame();
    ASSERT(mainFrame.document());

    // Make sure that this is in sync with ReplayController::beginCapturing().
    RefPtr<SecurityOrigin> originCopy = mainFrame.document()->securityOrigin()->isolatedCopy();
    URL url = mainFrame.document()->url();
    String referrer = mainFrame.loader().referrer();
    return std::make_unique<InitialNavigation>(originCopy, url, referrer);
}

} // namespace WebCore

#endif // ENABLE(WEB_REPLAY)

==> webkitgtk-2.16.4.tar.xz: webkitgtk-2.16.4/Source/WebCore/replay/ReplayInputCreationMethods.cpp <==
/*
 * Copyright (C) 2011-2013 University of Washington.
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#if ENABLE(WEB_REPLAY)

#include "Document.h"
#include "MainFrame.h"
#include "Page.h"
#include "SecurityOrigin.h"
#include "SerializationMethods.h"
#include "WebReplayInputs.h"

namespace WebCore {

std::unique_ptr<InitialNavigation> InitialNavigation::createFromPage(const Page& page)
{
    const MainFrame& mainFrame = page.mainFrame();
    ASSERT(mainFrame.document());

    // Make sure that this is in sync with ReplayController::beginCapturing().
    RefPtr<SecurityOrigin> originCopy = mainFrame.document()->securityOrigin().isolatedCopy();
    URL url = mainFrame.document()->url();
    String referrer = mainFrame.loader().referrer();
    return std::make_unique<InitialNavigation>(WTFMove(originCopy), url, referrer);
}

} // namespace WebCore

#endif // ENABLE(WEB_REPLAY)
